﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace IWS940Demo
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        /**
         * フォームがロードされた際の処理
         * */
        private void Form1_Load(object sender, EventArgs e)
        {
            tlTextBox.Text = iws940Component.ThresholdLevel.ToString();
            hystTextBox.Text = iws940Component.Hysteresis.ToString();
        }

        /**
         * フォームがクロースズされた際の処理
         * */
        private void Form1_FormClosed(object sender, FormClosedEventArgs e)
        {
            iws940Component.Close();
        }

        /**
         * "接続"ボタンがクリックされた際の処理
         * */
        private void connectButton_Click(object sender, EventArgs e)
        {
            try
            {
                if (iws940Component.IsConnected == true)
                {
                    connectButton.Text = "接続";
                    iws940Component.Close();
                }
                else
                {
                    PortSelectDialog dlg = new PortSelectDialog();
                    dlg.ShowDialog();

                    if (dlg.DialogResult != DialogResult.Cancel)
                    {
                        iws940Component.Open(dlg.PortName);
                        connectButton.Text = "切断";
                    }
                }
            }
            catch (Exception x)
            {
                MessageBox.Show(x.Message);
            }
        }
        
        /**
         * IWS940デバイスとの接続が完了した後に呼び出されます。
         * */
        private void iwS940Component_OnDeviceConnected(object sender, EventArgs e)
        {
            connectionLabel.Text = "弛緩";
            connectionLabel.BackColor = Color.Green;
        }

        /**
         * IWS940デバイスとの接続が切断された後に呼び出されます。
         * */
        private void iwS940Component_OnDeviceClosed(object sender, EventArgs e)
        {
            connectionLabel.Text = "接続なし";
            connectionLabel.BackColor = Color.Black;
        }

        /**
         * 筋電位の強さが閾値以上になった場合に呼び出されます。
         * */
        private void iwS940Component_OnMuscleContracted(object sender, EventArgs e)
        {

            try
            {
                Invoke((MethodInvoker)(() =>
                {
                    connectionLabel.Text = "収縮";
                    connectionLabel.BackColor = Color.Red;
                }));
            }
            catch (Exception x)
            {
                System.Diagnostics.Debug.WriteLine(x);
            }
        }

        /**
         * 筋電位の強さが閾値以下になった場合に呼び出されます。
         * */
        private void iwS940Component_OnMuscleRelaxed(object sender, EventArgs e)
        {
            try
            {
                Invoke((MethodInvoker)(() =>
                {
                    connectionLabel.Text = "弛緩";
                    connectionLabel.BackColor = Color.Green;
                }));
            }
            catch (Exception x)
            {
                System.Diagnostics.Debug.WriteLine(x);
            }
        }


        private void tlTextBox_TextChanged(object sender, EventArgs e)
        {
            try
            {
                iws940Component.ThresholdLevel = Double.Parse(tlTextBox.Text);
            }
            catch (Exception x)
            {
                System.Diagnostics.Debug.WriteLine(x.Message);
                return;
            }
        }

        private void hystTextBox_TextChanged(object sender, EventArgs e)
        {
            try
            {
                iws940Component.Hysteresis = Double.Parse(hystTextBox.Text);
            }
            catch (Exception x)
            {
                System.Diagnostics.Debug.WriteLine(x.Message);
                return;
            }

        }

        /**
         * 筋電強度が定期的に取得されるたびに呼び出されます.
         * */
        private void iws940Component_OnRawValueRecieved(object sender, double e)
        {
            try
            {
                Invoke((MethodInvoker)(() =>
                {
                    valueLabel.Text = String.Format("{0:f1}", e);
                }));
            }
            catch (Exception x)
            {
                System.Diagnostics.Debug.WriteLine(x);
            }

        }


    }
}
